@@ -1,9 +1,12 @@
+use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 
+#[derive(Serialize, Deserialize, Clone, PartialEq, Debug)]
+#[serde(default)]
 pub struct ExportPcap {
-    enabled: bool,
-    file_name: String,
-    directory: String,
+    pub(crate) enabled: bool,
+    pub(crate) file_name: String,
+    pub(crate) directory: String,
 }
 
 impl ExportPcap {
