@@ -77,19 +77,19 @@ mod tests {
             assert!(matches!(reader, MmdbReader::Custom(_)));
 
             // known IP
-            let res = get_asn(&IpAddr::from([61, 8, 0, 0]), &reader);
-            assert_eq!(res.code, "AS1221");
-            assert_eq!(res.name, "Telstra Limited");
+            let res = get_asn(&IpAddr::from([185, 72, 2, 28]), &reader);
+            assert_eq!(res.code, "AS202583");
+            assert_eq!(res.name, "AVATEL TELECOM, SA");
 
             // another known IP
-            let res = get_asn(&IpAddr::from([206, 180, 34, 99]), &reader);
-            assert_eq!(res.code, "AS63344");
-            assert_eq!(res.name, "The Reynolds and Reynolds Company");
+            let res = get_asn(&IpAddr::from([89, 187, 198, 0]), &reader);
+            assert_eq!(res.code, "AS210367");
+            assert_eq!(res.name, "Krajska zdravotni, a.s.");
 
             // known IPv6
-            let res = get_asn(&IpAddr::from_str("2806:230:2057::").unwrap(), &reader);
-            assert_eq!(res.code, "AS11888");
-            assert_eq!(res.name, "Television Internacional, S.A. de C.V.");
+            let res = get_asn(&IpAddr::from_str("2408:8957:6280::").unwrap(), &reader);
+            assert_eq!(res.code, "AS17622");
+            assert_eq!(res.name, "China Unicom Guangzhou network");
 
             // unknown IP
             let res = get_asn(&IpAddr::from([127, 0, 0, 1]), &reader);
@@ -106,31 +106,29 @@ mod tests {
     #[test]
     fn test_get_asn_with_custom_ipinfo_combined_reader() {
         let reader_1 = MmdbReader::from(
-            &String::from("resources/test/ipinfo_country_asn_sample.mmdb"),
+            &String::from("resources/test/ipinfo_lite_sample.mmdb"),
             ASN_MMDB,
         );
-        let reader_2 = MmdbReader::from(
-            &String::from("resources/test/ipinfo_country_asn_sample.mmdb"),
-            &[],
-        );
+        let reader_2 =
+            MmdbReader::from(&String::from("resources/test/ipinfo_lite_sample.mmdb"), &[]);
 
         for reader in vec![reader_1, reader_2] {
             assert!(matches!(reader, MmdbReader::Custom(_)));
 
             // known IP
-            let res = get_asn(&IpAddr::from([31, 171, 144, 141]), &reader);
-            assert_eq!(res.code, "AS197742");
-            assert_eq!(res.name, "IBB Energie AG");
+            let res = get_asn(&IpAddr::from([1, 0, 65, 1]), &reader);
+            assert_eq!(res.code, "AS18144");
+            assert_eq!(res.name, "Enecom,Inc.");
 
             // another known IP
-            let res = get_asn(&IpAddr::from([103, 112, 220, 111]), &reader);
-            assert_eq!(res.code, "AS134077");
-            assert_eq!(res.name, "Magik Pivot Company Limited");
+            let res = get_asn(&IpAddr::from([1, 6, 230, 0]), &reader);
+            assert_eq!(res.code, "AS4755");
+            assert_eq!(res.name, "TATA Communications formerly VSNL is Leading ISP");
 
             // known IPv6
-            let res = get_asn(&IpAddr::from_str("2a02:6ea0:f001::").unwrap(), &reader);
-            assert_eq!(res.code, "AS60068");
-            assert_eq!(res.name, "Datacamp Limited");
+            // let res = get_asn(&IpAddr::from_str("2a02:6ea0:f001::").unwrap(), &reader);
+            // assert_eq!(res.code, "AS60068");
+            // assert_eq!(res.name, "Datacamp Limited");
 
             // unknown IP
             let res = get_asn(&IpAddr::from([127, 0, 0, 1]), &reader);
