@@ -1,16 +1,17 @@
 //! Module defining the `AddressPortPair` struct, which represents a network address:port pair.
 
 use crate::Protocol;
+use std::net::IpAddr;
 
 /// Struct representing a network address:port pair.
-#[derive(PartialEq, Eq, Hash, Clone, Debug)]
+#[derive(PartialEq, Eq, Hash, Clone, Copy, Debug)]
 pub struct AddressPortPair {
     /// Network layer IPv4 or IPv6 source address.
-    pub address1: String,
+    pub address1: IpAddr,
     /// Transport layer source port number (in the range 0..=65535).
     pub port1: Option<u16>,
     /// Network layer IPv4 or IPv6 destination address.
-    pub address2: String,
+    pub address2: IpAddr,
     /// Transport layer destination port number (in the range 0..=65535).
     pub port2: Option<u16>,
     ///  Transport layer protocol carried through the associate address:port pair (TCP or UPD).
@@ -26,9 +27,9 @@ impl AddressPortPair {
     ///
     /// * `port` - An integer representing the transport layer port number (in the range 0..=65535).
     pub fn new(
-        address1: String,
+        address1: IpAddr,
         port1: Option<u16>,
-        address2: String,
+        address2: IpAddr,
         port2: Option<u16>,
         protocol: Protocol,
     ) -> Self {
