@@ -1,5 +1,7 @@
 use crate::countries::types::country::Country;
 use crate::networking::types::asn::Asn;
+use crate::networking::types::data_info_host::DataInfoHost;
+use std::net::IpAddr;
 
 /// Struct to represent a network host
 #[derive(Default, PartialEq, Eq, Hash, Clone, Debug)]
@@ -23,3 +25,11 @@ pub struct ThumbnailHost {
     /// Text describing the host in the thumbnail
     pub text: String,
 }
+
+#[derive(Clone, Debug)]
+pub struct HostMessage {
+    pub host: Host,
+    pub data_info_host: DataInfoHost,
+    pub address_to_lookup: IpAddr,
+    pub rdns: String,
+}
