@@ -216,15 +216,15 @@ impl IcmpTypeV6 {
             Icmpv6Type::ParameterProblem(_) => Self::ParameterProblem,
             Icmpv6Type::EchoRequest(_) => Self::EchoRequest,
             Icmpv6Type::EchoReply(_) => Self::EchoReply,
+            Icmpv6Type::RouterSolicitation => Self::RouterSolicitation,
+            Icmpv6Type::RouterAdvertisement(_) => Self::RouterAdvertisement,
+            Icmpv6Type::NeighborSolicitation => Self::NeighborSolicitation,
+            Icmpv6Type::NeighborAdvertisement(_) => Self::NeighborAdvertisement,
+            Icmpv6Type::Redirect => Self::RedirectMessage,
             Icmpv6Type::Unknown { type_u8: id, .. } => match id {
                 130 => Self::MulticastListenerQuery,
                 131 => Self::MulticastListenerReport,
                 132 => Self::MulticastListenerDone,
-                133 => Self::RouterSolicitation,
-                134 => Self::RouterAdvertisement,
-                135 => Self::NeighborSolicitation,
-                136 => Self::NeighborAdvertisement,
-                137 => Self::RedirectMessage,
                 138 => Self::RouterRenumbering,
                 139 => Self::ICMPNodeInformationQuery,
                 140 => Self::ICMPNodeInformationResponse,
