@@ -2,11 +2,11 @@ pub mod address_port_pair;
 pub mod arp_type;
 pub mod asn;
 pub mod bogon;
-pub mod byte_multiple;
 pub mod capture_context;
+pub mod config_device;
 pub mod data_info;
 pub mod data_info_host;
-pub mod filters;
+pub mod data_representation;
 pub mod host;
 pub mod host_data_states;
 pub mod icmp_type;
@@ -17,7 +17,6 @@ pub mod ip_version;
 pub mod my_device;
 pub mod my_link_type;
 pub mod packet_filters_fields;
-pub mod port_collection;
 pub mod protocol;
 pub mod service;
 pub mod service_query;
