@@ -1,15 +1,18 @@
 use serde::{Deserialize, Serialize};
 
 use crate::ByteMultiple;
-use crate::chart::types::chart_type::ChartType;
+use crate::networking::types::data_representation::DataRepr;
 use crate::notifications::types::sound::Sound;
 
 /// Used to contain the notifications configuration set by the user
-#[derive(Clone, Serialize, Deserialize, Copy, PartialEq, Debug)]
+#[derive(Clone, Serialize, Deserialize, PartialEq, Debug)]
+#[serde(default)]
 pub struct Notifications {
     pub volume: u8,
     pub data_notification: DataNotification,
     pub favorite_notification: FavoriteNotification,
+    #[allow(clippy::struct_field_names)]
+    pub remote_notifications: RemoteNotifications,
 }
 
 impl Default for Notifications {
@@ -18,6 +21,7 @@ impl Default for Notifications {
             volume: 60,
             data_notification: DataNotification::default(),
             favorite_notification: FavoriteNotification::default(),
+            remote_notifications: RemoteNotifications::default(),
         }
     }
 }
@@ -32,9 +36,10 @@ pub enum Notification {
 }
 
 #[derive(Clone, Eq, PartialEq, Serialize, Deserialize, Debug, Copy)]
+#[serde(default)]
 pub struct DataNotification {
     /// Data representation
-    pub chart_type: ChartType,
+    pub data_repr: DataRepr,
     /// Threshold of received + sent bytes; if exceeded a notification is emitted
     pub threshold: Option<u64>,
     /// B, KB, MB or GB
@@ -48,7 +53,7 @@ pub struct DataNotification {
 impl Default for DataNotification {
     fn default() -> Self {
         DataNotification {
-            chart_type: ChartType::Bytes,
+            data_repr: DataRepr::Bytes,
             threshold: None,
             byte_multiple: ByteMultiple::KB,
             sound: Sound::Pop,
@@ -101,6 +106,7 @@ impl DataNotification {
 }
 
 #[derive(Clone, Eq, PartialEq, Serialize, Deserialize, Debug, Copy)]
+#[serde(default)]
 pub struct FavoriteNotification {
     /// Flag to determine if this notification is enabled
     pub notify_on_favorite: bool,
@@ -135,6 +141,37 @@ impl FavoriteNotification {
     }
 }
 
+#[derive(Clone, Eq, PartialEq, Serialize, Deserialize, Debug, Default)]
+#[serde(default)]
+pub struct RemoteNotifications {
+    /// Flag to determine if remote notifications are enabled
+    is_active: bool,
+    /// The URL to send notifications to
+    url: String,
+}
+
+impl RemoteNotifications {
+    pub fn is_active(&self) -> bool {
+        self.is_active
+    }
+
+    pub fn url(&self) -> &str {
+        &self.url
+    }
+
+    pub fn toggle(&mut self) {
+        self.is_active = !self.is_active;
+    }
+
+    pub fn set_url(&mut self, url: &str) {
+        self.url = url.trim().to_string();
+    }
+
+    pub fn is_active_and_set(&self) -> bool {
+        self.is_active && !self.url.is_empty()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use rstest::rstest;
