@@ -1,4 +1,4 @@
-#![allow(clippy::match_same_arms)]
+#![allow(clippy::match_same_arms, clippy::match_wildcard_for_single_variants)]
 
 use iced::widget::Text;
 
@@ -9,6 +9,7 @@ use crate::{Language, StyleType};
 pub fn general_translation(language: Language) -> &'static str {
     match language {
         Language::EN | Language::RO => "General",
+        Language::CS => "Hlavní",
         // Language::FA => "عمومی",
         Language::ES => "Generales",
         Language::IT => "Generali",
@@ -27,6 +28,8 @@ pub fn general_translation(language: Language) -> &'static str {
         Language::PT => "Geral",
         Language::UK => "Загальні",
         Language::ID => "Umum",
+        Language::NL => "Algemeen",
+        Language::EL => "Γενικά",
         _ => "General",
     }
 }
@@ -40,7 +43,9 @@ pub fn zoom_translation(language: Language) -> &'static str {
         | Language::DE
         | Language::RO
         | Language::PT
+        | Language::NL
         | Language::SV => "Zoom",
+        Language::CS => "Přiblížení",
         // Language::FA => "بزرگنمایی",
         Language::PL => "Powiększenie",
         Language::RU => "Масштаб интерфейса",
@@ -53,6 +58,7 @@ pub fn zoom_translation(language: Language) -> &'static str {
         Language::TR => "Yakınlaştırma",
         Language::UK => "Масштабування",
         Language::ID => "Perbesar",
+        Language::EL => "Εστίαση",
         _ => "Zoom",
     }
 }
@@ -60,6 +66,7 @@ pub fn zoom_translation(language: Language) -> &'static str {
 pub fn mmdb_files_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Database files",
+        Language::CS => "Databázové soubory",
         // Language::FA => "پرونده های پایگاه داده",
         Language::ES => "Archivos de la base de datos",
         Language::IT => "File di database",
@@ -79,6 +86,8 @@ pub fn mmdb_files_translation(language: Language) -> &'static str {
         Language::PT => "Arquivos da base de dados",
         Language::UK => "Файли бази даних",
         Language::ID => "Berkas database",
+        Language::NL => "Database bestanden",
+        Language::EL => "Αρχεία βάσης δεδομένων",
         _ => "Database files",
     }
 }
@@ -86,6 +95,7 @@ pub fn mmdb_files_translation(language: Language) -> &'static str {
 pub fn params_not_editable_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "The following parameters can't be modified during the analysis",
+        Language::CS => "Následující parametry nelze během analýzy měnit",
         // Language::FA => "مولفه های روبرو هنگام تحلیل قابل تغییر نیستند",
         Language::ES => "Los siguientes parámetros no pueden modificarse durante el análisis",
         Language::IT => "I seguenti parametri non sono modificabili durante l'analisi",
@@ -95,7 +105,7 @@ pub fn params_not_editable_translation(language: Language) -> &'static str {
         Language::RU => "Следующие параметры не могут быть изменены во время анализа трафика",
         Language::RO => "Următorii parametri nu sunt modificabili în timpul analizei",
         Language::JA => "以下のパラメーターは分析中は変更できません",
-        Language::UZ => "Tahlil vaqtida quydagi parametrlarni o'zgartirib bo'lmaydi",
+        Language::UZ => "Tahlil vaqtida quyidagi parametrlarni o'zgartirib bo'lmaydi",
         Language::SV => "Följande parametrar kan inte ändras under analysen",
         Language::VI => "Các tham số sau không thể bị thay đổi khi đang phân tích",
         Language::ZH => "以下参数在分析过程中不能修改",
@@ -105,6 +115,10 @@ pub fn params_not_editable_translation(language: Language) -> &'static str {
         Language::PT => "Os seguintes parâmetros não podem ser modificados durante a análise",
         Language::UK => "Наступні параметри не можна змінювати під час аналізу трафіку",
         Language::ID => "Parameter berikut tidak bisa diubah saat dianalisa",
+        Language::NL => "De volgende parameters kunnen niet worden aangepast tijdens de analyse",
+        Language::EL => {
+            "Οι ακόλουθες παράμετροι δεν μπορούν να τροποποιηθούν κατά τη διάρκεια της ανάλυσης"
+        }
         _ => "The following parameters can't be modified during the analysis",
     }
 }
@@ -112,6 +126,7 @@ pub fn params_not_editable_translation(language: Language) -> &'static str {
 pub fn custom_style_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Custom style",
+        Language::CS => "Vlastní styl",
         // Language::FA => "شیوه سفارشی",
         Language::ES | Language::PT => "Estilo personalizado",
         Language::IT => "Stile personalizzato",
@@ -130,6 +145,8 @@ pub fn custom_style_translation(language: Language) -> &'static str {
         Language::TR => "Kişisel görünüm",
         Language::UK => "Власний стиль",
         Language::ID => "Ubah Model",
+        Language::NL => "Aangepaste stijl",
+        Language::EL => "Προσαρμοσμένο στυλ",
         _ => "Custom style",
     }
 }
@@ -137,6 +154,7 @@ pub fn custom_style_translation(language: Language) -> &'static str {
 pub fn copy_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Copy",
+        Language::CS => "Kopírovat",
         // Language::FA => "رونوشت",
         Language::IT | Language::ES => "Copia",
         Language::FR | Language::RO => "Copie",
@@ -154,6 +172,8 @@ pub fn copy_translation(language: Language) -> &'static str {
         Language::PT => "Copiar",
         Language::UK => "Копіювати",
         Language::ID => "Salin",
+        Language::NL => "Kopiëren",
+        Language::EL => "Αντιγραφή",
         _ => "Copy",
     }
 }
@@ -161,6 +181,7 @@ pub fn copy_translation(language: Language) -> &'static str {
 pub fn port_translation(language: Language) -> &'static str {
     match language {
         Language::EN
+        | Language::CS
         | Language::FR
         | Language::DE
         | Language::PL
@@ -179,38 +200,44 @@ pub fn port_translation(language: Language) -> &'static str {
         Language::KO => "포트",
         Language::UK => "Порт",
         Language::ID => "Port",
+        Language::NL => "Poort",
+        Language::EL => "Θύρα",
         _ => "Port",
     }
 }
 
-pub fn invalid_filters_translation(language: Language) -> &'static str {
-    match language {
-        Language::EN => "Invalid filters",
-        // Language::FA => "صافی نامعتبر",
-        Language::ES | Language::PT => "Filtros inválidos",
-        Language::IT => "Filtri non validi",
-        Language::FR => "Filtres invalides",
-        Language::DE => "Ungültige Filter",
-        Language::PL => "Nieprawidłowe filtry",
-        Language::RU => "Неверный формат фильтров",
-        Language::RO => "Filtre invalide",
-        Language::JA => "無効なフィルター",
-        Language::UZ => "Noto'g'ri filterlar",
-        Language::SV => "Ogiltiga filter",
-        Language::VI => "Bộ lọc không khả dụng",
-        Language::ZH => "无效的过滤器",
-        Language::ZH_TW => "無效的篩選器",
-        Language::KO => "잘못된 필터",
-        Language::TR => "Geçersiz filtreler",
-        Language::UK => "Неправильний формат фільтрів",
-        Language::ID => "Filter salah",
-        _ => "Invalid filters",
-    }
-}
+// pub fn invalid_filters_translation(language: Language) -> &'static str {
+//     match language {
+//         Language::EN => "Invalid filters",
+//         Language::CS => "Neplatné filtry",
+//         // Language::FA => "صافی نامعتبر",
+//         Language::ES | Language::PT => "Filtros inválidos",
+//         Language::IT => "Filtri non validi",
+//         Language::FR => "Filtres invalides",
+//         Language::DE => "Ungültige Filter",
+//         Language::PL => "Nieprawidłowe filtry",
+//         Language::RU => "Неверный формат фильтров",
+//         Language::RO => "Filtre invalide",
+//         Language::JA => "無効なフィルター",
+//         Language::UZ => "Noto'g'ri filterlar",
+//         Language::SV => "Ogiltiga filter",
+//         Language::VI => "Bộ lọc không khả dụng",
+//         Language::ZH => "无效的过滤器",
+//         Language::ZH_TW => "無效的篩選器",
+//         Language::KO => "잘못된 필터",
+//         Language::TR => "Geçersiz filtreler",
+//         Language::UK => "Неправильний формат фільтрів",
+//         Language::ID => "Filter salah",
+//         Language::NL => "Ongeldige filters",
+//         Language::EL => "Μη έγκυρα φίλτρα",
+//         _ => "Invalid filters",
+//     }
+// }
 
 pub fn messages_translation(language: Language) -> &'static str {
     match language {
         Language::EN | Language::FR => "Messages",
+        Language::CS => "Zprávy",
         // Language::FA => "پیام ها",
         Language::ES => "Mensajes",
         Language::IT => "Messaggi",
@@ -229,13 +256,16 @@ pub fn messages_translation(language: Language) -> &'static str {
         Language::PT => "Mensagens",
         Language::UK => "Повідомлення",
         Language::ID => "Pesan",
+        Language::NL => "Berichten",
+        Language::EL => "Μηνύματα",
         _ => "Messages",
     }
 }
 
 pub fn link_type_translation(language: Language) -> &'static str {
     match language {
-        Language::EN => "Link type",
+        Language::EN | Language::NL => "Link type",
+        Language::CS => "Typ linky",
         // Language::FA => "نوع پیوند",
         Language::ES => "Tipo de conexión",
         Language::IT => "Tipo di collegamento",
@@ -255,6 +285,7 @@ pub fn link_type_translation(language: Language) -> &'static str {
         Language::PT => "Tipo de conexão",
         Language::UK => "Різновид зʼєднання",
         Language::ID => "Tipe koneksi",
+        Language::EL => "Τύπος σύνδεσης",
         _ => "Link type",
     }
 }
@@ -267,6 +298,9 @@ pub fn unsupported_link_type_translation<'a>(
         Language::EN => {
             "The link type associated with this adapter is not supported by Sniffnet yet..."
         }
+        Language::CS => {
+            "Typ linky přidružený k tomuto adaptéru zatím není Sniffnetem podporován...."
+        }
         // Language::FA => "نوع پیوند مرتبط با این مبدل هنوز توسط Sniffnet پشتیبانی نمی شود...",
         Language::ES => {
             "La conexión asociada a este adaptador aún no está soportada por Sniffnet..."
@@ -312,6 +346,12 @@ pub fn unsupported_link_type_translation<'a>(
         Language::ID => {
             "Tipe koneksi yang terhubung dengan adaptor ini belum didukung oleh Sniffnet"
         }
+        Language::NL => {
+            "Het linktype dat is gekoppeld aan deze adapter wordt nog niet ondersteund door Sniffnet..."
+        }
+        Language::EL => {
+            "Ο τύπος σύνδεσης που σχετίζεται με αυτόν τον προσαρμογέα δεν υποστηρίζεται ακόμη από το Sniffnet..."
+        }
         _ => "The link type associated with this adapter is not supported by Sniffnet yet...",
     };
 
@@ -324,6 +364,7 @@ pub fn unsupported_link_type_translation<'a>(
 pub fn style_from_file_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Select style from a file",
+        Language::CS => "Výběr stylu ze souboru",
         // Language::FA => "انتخاب شیوه از یک پرونده",
         Language::ES => "Selecciona el estilo desde un archivo",
         Language::IT => "Seleziona lo stile da un file",
@@ -343,6 +384,8 @@ pub fn style_from_file_translation(language: Language) -> &'static str {
         Language::PT => "Selecionar estilo a partir de um arquivo",
         Language::UK => "Виберіть стиль з файлу",
         Language::ID => "Pilih model / gaya dari berkas",
+        Language::NL => "Selecteer stijl vanuit een bestand",
+        Language::EL => "Επιλογή στυλ από αρχείο",
         _ => "Select style from a file",
     }
 }
@@ -350,6 +393,7 @@ pub fn style_from_file_translation(language: Language) -> &'static str {
 pub fn database_from_file_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Select database file",
+        Language::CS => "Výběr souboru databáze",
         // Language::FA => "پرونده پایگاه داده را انتخاب کنید",
         Language::ES => "Selecciona un archivo de base de datos",
         Language::IT => "Seleziona file di database",
@@ -369,6 +413,8 @@ pub fn database_from_file_translation(language: Language) -> &'static str {
         Language::PT => "Selecione um arquivo de base de dados",
         Language::UK => "Виберіть файл бази даних",
         Language::ID => "Pilih berkas database",
+        Language::NL => "Selecteer database bestand",
+        Language::EL => "Επιλογή αρχείου βάσης δεδομένων",
         _ => "Select database file",
     }
 }
@@ -376,6 +422,7 @@ pub fn database_from_file_translation(language: Language) -> &'static str {
 pub fn filter_by_host_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Filter by network host",
+        Language::CS => "Filtrovat podle síťového hostitele",
         // Language::FA => "صافی بر اساس میزبان شبکه",
         Language::ES => "Filtra por host de red",
         Language::IT => "Filtra per host di rete",
@@ -385,7 +432,7 @@ pub fn filter_by_host_translation(language: Language) -> &'static str {
         Language::RU => "Фильтр по сетевому хосту",
         Language::RO => "Filtrează după host-ul de rețea",
         Language::JA => "ネットワーク ホストでフィルター",
-        Language::UZ => "Tarmoq host bo'yicha filterlash",
+        Language::UZ => "Tarmoq xosti bo'yicha filtrlash",
         Language::SV => "Filtrera efter nätverksvärd",
         Language::VI => "Lọc bởi máy chủ mạng",
         Language::ZH => "按网络主机筛选",
@@ -395,6 +442,8 @@ pub fn filter_by_host_translation(language: Language) -> &'static str {
         Language::PT => "Filtrar por host de rede",
         Language::UK => "Фільтр за хостом мережі",
         Language::ID => "Filter berdasarkan jaringan asal",
+        Language::NL => "Filteren op netwerk host",
+        Language::EL => "Φίλτρο ανά διακομιστή δικτύου",
         _ => "Filter by network host",
     }
 }
@@ -402,6 +451,7 @@ pub fn filter_by_host_translation(language: Language) -> &'static str {
 pub fn service_translation(language: Language) -> &'static str {
     match language {
         Language::EN | Language::FR | Language::DE | Language::SV => "Service",
+        Language::CS => "Služba",
         // Language::FA => "خدمت",
         Language::ES => "Servicio",
         Language::IT => "Servizio",
@@ -418,6 +468,8 @@ pub fn service_translation(language: Language) -> &'static str {
         Language::PT => "Serviço",
         Language::UK => "Сервіс",
         Language::ID => "Layanan",
+        Language::NL => "Dienst",
+        Language::EL => "Υπηρεσία",
         _ => "Service",
     }
 }
@@ -425,6 +477,7 @@ pub fn service_translation(language: Language) -> &'static str {
 pub fn export_capture_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Export capture file",
+        Language::CS => "Export souboru zachycení",
         // Language::FA => "خروجی گرفتن پرونده تسخیری",
         Language::IT => "Esporta file di cattura",
         Language::FR => "Exporter le fichier de capture",
@@ -433,7 +486,7 @@ pub fn export_capture_translation(language: Language) -> &'static str {
         Language::RU => "Экспорт файла захвата",
         Language::RO => "Export fișier captură",
         Language::JA => "キャプチャ ファイルをエクスポート",
-        Language::UZ => "Cap faylni export qilish",
+        Language::UZ => "Cap faylni eksport qilish",
         Language::SV => "Exportera inspelningsfil",
         Language::VI => "Xuất tập tin đã bắt",
         Language::ZH => "导出捕获文件",
@@ -444,6 +497,8 @@ pub fn export_capture_translation(language: Language) -> &'static str {
         Language::UK => "Експорт файлу захоплення",
         Language::ID => "Ekspor data tangkapan",
         Language::ES => "Exportar archivo de captura",
+        Language::NL => "Exporteer capture bestand",
+        Language::EL => "Εξαγωγή αρχείου καταγραφής",
         _ => "Export capture file",
     }
 }
@@ -452,6 +507,7 @@ pub fn export_capture_translation(language: Language) -> &'static str {
 pub fn directory_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Directory",
+        Language::CS => "Složka",
         // Language::FA => "پوشه",
         Language::IT => "Cartella",
         Language::FR => "Répertoire",
@@ -469,6 +525,8 @@ pub fn directory_translation(language: Language) -> &'static str {
         Language::UK => "Тека",
         Language::ID => "Direktori",
         Language::ES => "Directorio",
+        Language::NL => "Map",
+        Language::EL => "Κατάλογος",
         _ => "Directory",
     }
 }
@@ -476,6 +534,7 @@ pub fn directory_translation(language: Language) -> &'static str {
 pub fn select_directory_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Select destination directory",
+        Language::CS => "Výběr cílové složky",
         // Language::FA => "انتخاب پوشه مقصد",
         Language::IT => "Seleziona cartella di destinazione",
         Language::FR => "Sélectionner le répertoire de destination",
@@ -495,6 +554,8 @@ pub fn select_directory_translation(language: Language) -> &'static str {
         Language::UK => "Виберіть теку призначення",
         Language::ID => "Pilih direktori tujuan",
         Language::ES => "Selecciona el directorio de destino",
+        Language::NL => "Selecteer doelmap",
+        Language::EL => "Επιλογή καταλόγου προορισμού",
         _ => "Select destination directory",
     }
 }
@@ -502,6 +563,7 @@ pub fn select_directory_translation(language: Language) -> &'static str {
 pub fn file_name_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "File name",
+        Language::CS => "Jméno souboru",
         // Language::FA => "نام پرونده",
         Language::IT => "Nome del file",
         Language::FR => "Nom du fichier",
@@ -521,6 +583,8 @@ pub fn file_name_translation(language: Language) -> &'static str {
         Language::UK => "Назва файлу",
         Language::ID => "Nama berkas",
         Language::ES => "Nombre del archivo",
+        Language::NL => "Bestandsnaam",
+        Language::EL => "Όνομα αρχείου",
         _ => "File name",
     }
 }
@@ -528,6 +592,7 @@ pub fn file_name_translation(language: Language) -> &'static str {
 pub fn thumbnail_mode_translation(language: Language) -> &'static str {
     match language {
         Language::EN => "Thumbnail mode",
+        Language::CS => "Režim miniatury",
         // Language::FA => "حالت تصویر بندانگشتی",
         Language::IT => "Modalità miniatura",
         Language::FR => "Mode miniature",
@@ -536,7 +601,7 @@ pub fn thumbnail_mode_translation(language: Language) -> &'static str {
         Language::RU => "Режим миниатюры",
         Language::RO => "Mod thumbnail",
         Language::JA => "サムネイル モード",
-        Language::UZ => "Eskiz rejim",
+        Language::UZ => "Kichik rasm rejimi",
         Language::SV => "Miniatyrläge",
         Language::VI => "Chế độ thu nhỏ",
         Language::ZH => "缩略图模式",
@@ -546,6 +611,8 @@ pub fn thumbnail_mode_translation(language: Language) -> &'static str {
         Language::PT | Language::ES => "Modo miniatura",
         Language::UK => "Режим мініатюри",
         Language::ID => "Mode gambar kecil",
+        Language::NL => "Miniatuur modus",
+        Language::EL => "Λειτουργία μικρογραφιών",
         _ => "Thumbnail mode",
     }
 }
@@ -553,6 +620,7 @@ pub fn thumbnail_mode_translation(language: Language) -> &'static str {
 // pub fn learn_more_translation(language: Language) -> &'static str {
 //     match language {
 //         Language::EN => "Do you want to learn more?",
+//         Language::CS => "Chcete se dozvědět více?",
 //         // Language::FA => "آیا می خواهید بیشتر یاد بگیرید؟",
 //         Language::IT => "Vuoi saperne di più?",
 //         Language::FR => "Voulez-vous en savoir davantage?",
@@ -572,6 +640,7 @@ pub fn thumbnail_mode_translation(language: Language) -> &'static str {
 //         Language::UK => "Бажаєте дізнатись більше?",
 //         Language::ID => "Apakah kamu mau belajar lebih lanjut?",
 //         Language::ES => "¿Quieres aprender más?",
+//         Language::NL => "Wil je meer leren?",
 //         _ => "Do you want to learn more?",
 //     }
 // }
